"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withMiddleware = void 0;
exports.patchHeaders = patchHeaders;
var tslib_1 = require("tslib");
var headers_1 = require("next/headers");
var navigation_1 = require("next/navigation");
/**
 * @see {@link https://www.propelauth.com/post/getting-url-in-next-server-components}
 */
function patchHeaders(request) {
    var _a;
    var resolvedUrl = request.nextUrl + '', _b = request.nextUrl, locale = _b.locale, _c = _b.defaultLocale, defaultLocale = _c === void 0 ? '' : _c, domainLocale = _b.domainLocale, headers = new Headers(request.headers);
    var locales = ((_a = domainLocale === null || domainLocale === void 0 ? void 0 : domainLocale.locales) === null || _a === void 0 ? void 0 : _a.join(',')) || locale;
    headers.set('x-resolved-url', resolvedUrl);
    headers.set('x-locale', locale);
    headers.set('x-locales', locales);
    headers.set('x-default-locale', defaultLocale);
    return headers;
}
var withMiddleware = function (getServerSideProps, serverComponent) {
    return function (_a) { return tslib_1.__awaiter(void 0, [_a], void 0, function (_b) {
        var resolvedParams, resolvedSearchParams, header, cookie, isEnabled, url, locale, locales, defaultLocale, req, context, result, isPermanent, destination, props;
        var _c;
        var params = _b.params, searchParams = _b.searchParams;
        return tslib_1.__generator(this, function (_d) {
            switch (_d.label) {
                case 0: return [4 /*yield*/, params];
                case 1:
                    resolvedParams = _d.sent();
                    return [4 /*yield*/, searchParams];
                case 2:
                    resolvedSearchParams = _d.sent();
                    return [4 /*yield*/, (0, headers_1.headers)()];
                case 3:
                    header = _d.sent();
                    return [4 /*yield*/, (0, headers_1.cookies)()];
                case 4:
                    cookie = _d.sent();
                    return [4 /*yield*/, (0, headers_1.draftMode)()];
                case 5:
                    isEnabled = (_d.sent()).isEnabled;
                    url = header.get('x-resolved-url') || '', locale = header.get('x-locale') || '', locales = ((_c = header.get('x-locales')) === null || _c === void 0 ? void 0 : _c.split(',')) || [], defaultLocale = header.get('x-default-locale') || '';
                    req = {
                        url: url,
                        headers: Object.fromEntries(tslib_1.__spreadArray([], tslib_1.__read(header), false)),
                        cookies: Object.fromEntries(cookie.getAll().map(function (_a) {
                            var name = _a.name, value = _a.value;
                            return [name, value];
                        }))
                    };
                    context = {
                        req: req,
                        res: {},
                        params: resolvedParams,
                        query: resolvedSearchParams,
                        preview: false,
                        previewData: {},
                        draftMode: isEnabled,
                        resolvedUrl: url,
                        locale: locale,
                        locales: locales,
                        defaultLocale: defaultLocale
                    };
                    return [4 /*yield*/, getServerSideProps(context)];
                case 6:
                    result = _d.sent();
                    if ('redirect' in result) {
                        isPermanent = 'statusCode' in result.redirect
                            ? result.redirect.statusCode === 308
                            : 'permanent' in result.redirect &&
                                result.redirect.permanent;
                        destination = result.redirect.destination;
                        if (isPermanent)
                            (0, navigation_1.permanentRedirect)(destination);
                        else
                            (0, navigation_1.redirect)(destination);
                    }
                    if (!('props' in result)) return [3 /*break*/, 8];
                    return [4 /*yield*/, result.props];
                case 7:
                    props = _d.sent();
                    return [2 /*return*/, serverComponent(tslib_1.__assign({ params: params, searchParams: searchParams }, props))];
                case 8: return [2 /*return*/];
            }
        });
    }); };
};
exports.withMiddleware = withMiddleware;
//# sourceMappingURL=shim.js.map